#!/bin/tclsh

package require Gnocl

proc showError { message} {
	gnocl::dialog -type error -title "Remote desktop client" -text $message

}

proc createStandardEntryFrame {} {
	return [gnocl::box -orientation horizontal -borderWidth 0 -align left]
}

proc showHideNotebook {} {
	global optionsVisible
	global optionsFrame
	global hostFrame
	global hostEntry
	global hostEntry2

	
	if { $optionsVisible } {
		set optionsVisible false
		$hostEntry configure -hasFocus true
	} else {
		set optionsVisible true
		$hostEntry2 configure -hasFocus true
	}
		
	$hostFrame configure -visible [expr ! $optionsVisible ]
	$optionsFrame configure -visible $optionsVisible
}

proc buildMainWindow {} {
	global optionsFrame
	global optionsNotebook
	global optionsVisible
	global hostFrame
	global hostEntry
	
	set mainWin [gnocl::window -title "Remote desktop client" -onDestroy {exit} -allowGrow false -resizable false -x 50 -y 50]
	set mainFrame [gnocl::box -orientation vertical -borderWidth 0 -spacing 0]
	$mainWin configure -child $mainFrame

	global scriptpath
	append imagefilename "%/" $scriptpath "/remotedesktopclient.png"
	
	$mainFrame add [set headerImg [gnocl::image -image $imagefilename]]

	$mainFrame add [set hostFrame [gnocl::box -orientation horizontal -align left]]
	$hostFrame add [set hostLbl [gnocl::label -text "Hostname " -widthChars 11 -align right]]
	$hostFrame add [set hostEntry [gnocl::entry -variable hostname]]

	$mainFrame add [set optionsFrame [gnocl::box -orientation vertical]]
	$optionsFrame configure -visible $optionsVisible

	$optionsFrame add [set optionsNotebook [gnocl::notebook]]

	addGeneralTab
	addDisplayTab
	addResourcesTab
	addExperienceTab
	
	$mainFrame add [set btnFrame [gnocl::box -orientation horizontal -buttonType 1 -layout end -spacing small]]
	$btnFrame add [gnocl::button -text "Connect" -icon "%#Network" -widthGroup buttons -onClicked { connect }]
	$btnFrame add [gnocl::button -text "%#Cancel" -widthGroup buttons -onClicked { exit }]
	#$btnFrame add [gnocl::button -text "%#Help" -widthGroup buttons -onClicked {exit}]
	$btnFrame add [gnocl::button -text "Options" -icon "%#Preferences" -widthGroup buttons -onClicked {showHideNotebook}]

	$hostEntry configure -hasFocus true
}

proc addGeneralTab {} {
	global hostEntry2
	global optionsNotebook
	$optionsNotebook addPage [set generaPage [gnocl::box -orientation vertical -spacing small]] "General"
	
	$generaPage add [set loginFrame [gnocl::box -orientation vertical -spacing normal -shadow etchedIn -label "Login settings"]]

	$loginFrame add [set hostFrame2 [createStandardEntryFrame]]
	$hostFrame2 add [gnocl::label -text "Hostname " -widthChars 10 -align right]
	$hostFrame2 add [set hostEntry2 [gnocl::entry -variable hostname]]

	$loginFrame add [set userFrame [createStandardEntryFrame]]
	$userFrame add [gnocl::label -text "Username " -widthChars 10 -align right]
	$userFrame add [set userEntry [gnocl::entry -variable username]]

	$loginFrame add [set passwordFrame [createStandardEntryFrame]]
	$passwordFrame add [gnocl::label -text "Password " -widthChars 10 -align right]
	$passwordFrame add [set passwordEntry [gnocl::entry -variable password -textVisible false]]

	$loginFrame add [set domainFrame [createStandardEntryFrame]]
	$domainFrame add [gnocl::label -text "Domain " -widthChars 10 -align right]
	$domainFrame add [set domainEntry [gnocl::entry -variable domain]]

	$loginFrame add [set consoleFrame [createStandardEntryFrame]]
	$consoleFrame add [gnocl::label -text " " -widthChars 10 -align right]
	$consoleFrame add [set consoleCheck [gnocl::checkButton -text "Console mode" -relief half -variable consolemode]]
	
	$generaPage add [set fileFrame [gnocl::box -orientation horizontal -buttonType 1 -layout spread -label "Save current settings or open saved connection" -shadow etchedIn]]
	$fileFrame add [gnocl::button -text "%#Save" -widthGroup buttons -onClicked {saveProfile}]
	$fileFrame add [gnocl::button -text "%#Open" -widthGroup buttons -onClicked {loadProfile}]

}

proc addDisplayTab {} {
	global optionsNotebook
	$optionsNotebook addPage [set displayPage [gnocl::box -orientation vertical -spacing small]] "Display"
	
	$displayPage add [set sizeFrame [gnocl::box -orientation vertical -spacing small -shadow etchedIn -label "Remote desktop size"]]
	$sizeFrame add [gnocl::label -align left -text  "Choose the screen resolution for your remote desktop."]
	$sizeFrame add [set sizeFrameIn [createStandardEntryFrame]]
	$sizeFrameIn add [gnocl::label -text " " -widthChars 5 -align right]
	$sizeFrameIn add [set displayCombo [gnocl::optionMenu -items {"640x480" "800x600" "1024x768" "Full Screen"} -variable displaysize]]

	$displayPage add [set colorsFrame [gnocl::box -orientation vertical -spacing small -shadow etchedIn -label "Colors"]]
	$colorsFrame add [set colorsFrameIn [createStandardEntryFrame]]
	$colorsFrameIn add [gnocl::label -text " " -widthChars 5 -align right]
	$colorsFrameIn add [set displayCombo [gnocl::optionMenu -items {"256" "65,000" "Millions"} -variable colors]]
	$colorsFrame add [gnocl::label -align left -text  "Note: Settings on the remote computer might\noverride this setting"]

}

proc addResourcesTab {} {
	global optionsNotebook
	$optionsNotebook addPage [set resourcesPage [gnocl::box -orientation vertical -spacing small]] "Local Resources"
	
	$resourcesPage add [set soundFrame [gnocl::box -orientation vertical -spacing small -shadow etchedIn -label "Remote computer sound"]]
	$soundFrame add [set soundFrameIn [createStandardEntryFrame]]
	$soundFrameIn add [gnocl::label -text " " -widthChars 5 -align right]
	$soundFrameIn add [set displayCombo [gnocl::optionMenu -items {"Bring to this computer" "Keep in remote computer" "No sound"} -variable sound]]

	$resourcesPage add [set keyboardFrame [gnocl::box -orientation vertical -spacing small -shadow etchedIn -label "Keyboard"]]
	$keyboardFrame add [gnocl::label -align left -text  "Keep window manager key bindings (for example Alt-Tab)"]
	$keyboardFrame add [set keyboardFrameIn [createStandardEntryFrame]]
	$keyboardFrameIn add [gnocl::label -text " " -widthChars 5 -align right]
	$keyboardFrameIn add [set displayCombo [gnocl::optionMenu -items {"In full screen mode only" "Always" "Never"} -variable keyboardbindings]]

	$resourcesPage add [set devicesFrame [gnocl::box -orientation vertical -spacing small -shadow etchedIn -label "Local devices"]]
	$devicesFrame add [gnocl::label -align left -text  "Connect automatically to these local devices when logged on\nto the remote computer:"]

	$devicesFrame add [set disksFrame [createStandardEntryFrame]]
	#$disksFrame add [gnocl::label -text " " -widthChars 5 -align right]
	$disksFrame add [set consoleCheck [gnocl::checkButton -text "Disk drives" -relief half -variable disks]]

	#$devicesFrame add [set comFrame [createStandardEntryFrame]]
	#$comFrame add [gnocl::label -text " " -widthChars 5 -align right]
	$disksFrame add [set consoleCheck [gnocl::checkButton -text "Com ports" -relief half -variable comports]]

}

proc addExperienceTab {} {
	global optionsNotebook
	$optionsNotebook addPage [set experiencePage [gnocl::box -orientation vertical -spacing small]] "Experience"

	$experiencePage add [gnocl::label -align left -text  "Choose your connection speed to optimize performance"]
	$experiencePage add [set speedFrame [createStandardEntryFrame]]
	$speedFrame add [gnocl::label -text " " -widthChars 5 -align right]
	$speedFrame add [set displayCombo [gnocl::optionMenu -items {"Modem (dial-up)" "Broadband (high speed)" "LAN (10Mbps or higher)"} -variable connectionspeed]]

	$experiencePage add [gnocl::label -align left -text  "\nAllow the following"]
	
	$experiencePage add [set bitmapCachingFrame [createStandardEntryFrame]]
	$bitmapCachingFrame add [gnocl::label -text " " -widthChars 5 -align right]
	$bitmapCachingFrame add [set consoleCheck [gnocl::checkButton -text "Bitmap caching" -relief half -variable bitmapcaching]]

	$experiencePage add [set compressionFrame [createStandardEntryFrame]]
	$compressionFrame add [gnocl::label -text " " -widthChars 5 -align right]
	$compressionFrame add [set consoleCheck [gnocl::checkButton -text "Enable compression" -relief half -variable compression]]

	$experiencePage add [set bitmapUpdatesFrame [createStandardEntryFrame]]
	$bitmapUpdatesFrame add [gnocl::label -text " " -widthChars 5 -align right]
	$bitmapUpdatesFrame add [set consoleCheck [gnocl::checkButton -text "Force bitmap updates" -relief half -variable bitmapupdates]]
	
	$experiencePage add [set mouseMotionFrame [createStandardEntryFrame]]
	$mouseMotionFrame add [gnocl::label -text " " -widthChars 5 -align right]
	$mouseMotionFrame add [set consoleCheck [gnocl::checkButton -text "Do not send mouse motion events" -relief half -variable mousemotion]]

}

proc getOpenFileName { defaultFolder } {
	set filename [gnocl::fileChooser -title "Please choose an rdp connection file" -currentFolder $defaultFolder ]

	return $filename
}

proc getSaveFileName { currentFileName } {
	return [gnocl::fileChooser -action save -title "Please choose a name rdp connection file" -currentFolder [file dirname $currentFileName] -currentName [file tail $currentFileName ]]
}
